#! /usr/bin/env bash

alias today="date +%Y-%m-%d"

alias @batch=abcli_aws_batch

alias @docker=abcli_docker

alias @notebook=abcli_notebooks
alias @notebooks=abcli_notebooks

alias @mv="abcli_scripts move"

alias @sagemaker=abcli_sagemaker

alias @scripts=abcli_scripts
alias @source="abcli_scripts source"

# meta scripts
alias roofserver="abcli_meta_scripts roofserver"
alias sagesemseg="abcli_meta_scripts sagesemseg"
