NAME = "blueflow"

ICON = "📜"

DESCRIPTION = f"{ICON} workflow management on aws batch and more."

VERSION = "4.769.1"

REPO_NAME = "notebooks-and-scripts"

MARQUEE = "https://github.com/kamangir/assets/raw/main/nbs/3x4.jpg?raw=true"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
